@@ -3,12 +3,11 @@ import warnings
 
 import graphene
 import pendulum
-import yaml
 
 import dagster._check as check
-from dagster.core.definitions.schedule_definition import ScheduleExecutionData
-from dagster.core.definitions.sensor_definition import RunRequest
-from dagster.core.scheduler.instigation import (
+from dagster._core.definitions.schedule_definition import ScheduleExecutionData
+from dagster._core.definitions.sensor_definition import RunRequest
+from dagster._core.scheduler.instigation import (
     InstigatorState,
     InstigatorTick,
     InstigatorType,
@@ -16,15 +15,16 @@ from dagster.core.scheduler.instigation import (
     SensorInstigatorData,
     TickStatus,
 )
-from dagster.core.storage.pipeline_run import RunsFilter
-from dagster.core.storage.tags import TagType, get_tag_type
-from dagster.seven.compat.pendulum import to_timezone
-from dagster.utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
+from dagster._core.storage.pipeline_run import DagsterRun, RunsFilter
+from dagster._core.storage.tags import REPOSITORY_LABEL_TAG, TagType, get_tag_type
+from dagster._seven.compat.pendulum import to_timezone
+from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
+from dagster._utils.yaml_utils import dump_run_config_yaml
 
 from ..implementation.fetch_schedules import get_schedule_next_tick
 from ..implementation.fetch_sensors import get_sensor_next_tick
 from ..implementation.loader import RepositoryScopedBatchLoader
-from .errors import GraphenePythonError
+from .errors import GrapheneError, GraphenePythonError
 from .repository_origin import GrapheneRepositoryOrigin
 from .tags import GraphenePipelineTag
 from .util import non_null_list
@@ -247,7 +247,7 @@ class GrapheneRunRequest(graphene.ObjectType):
         ]
 
     def resolve_runConfigYaml(self, _graphene_info):
-        return yaml.dump(self._run_request.run_config, default_flow_style=False, allow_unicode=True)
+        return dump_run_config_yaml(self._run_request.run_config)
 
 
 class GrapheneFutureInstigationTicks(graphene.ObjectType):
@@ -350,10 +350,21 @@ class GrapheneInstigationState(graphene.ObjectType):
             )
             return [GrapheneRun(record) for record in records]
 
+        repository_label = self._instigator_state.origin.external_repository_origin.get_label()
         if self._instigator_state.instigator_type == InstigatorType.SENSOR:
-            filters = RunsFilter.for_sensor(self._instigator_state)
+            filters = RunsFilter(
+                tags={
+                    **DagsterRun.tags_for_sensor(self._instigator_state),
+                    REPOSITORY_LABEL_TAG: repository_label,
+                }
+            )
         else:
-            filters = RunsFilter.for_schedule(self._instigator_state)
+            filters = RunsFilter(
+                tags={
+                    **DagsterRun.tags_for_schedule(self._instigator_state),
+                    REPOSITORY_LABEL_TAG: repository_label,
+                }
+            )
         return [
             GrapheneRun(record)
             for record in graphene_info.context.instance.get_run_records(
@@ -447,10 +458,27 @@ class GrapheneInstigationStates(graphene.ObjectType):
         name = "InstigationStates"
 
 
+class GrapheneInstigationStateNotFoundError(graphene.ObjectType):
+    class Meta:
+        interfaces = (GrapheneError,)
+        name = "InstigationStateNotFoundError"
+
+    name = graphene.NonNull(graphene.String)
+
+    def __init__(self, name):
+        super().__init__()
+        self.name = check.str_param(name, "name")
+        self.message = f"Could not find `{name}` in the currently loaded repository."
+
+
 class GrapheneInstigationStateOrError(graphene.Union):
     class Meta:
         name = "InstigationStateOrError"
-        types = (GrapheneInstigationState, GraphenePythonError)
+        types = (
+            GrapheneInstigationState,
+            GrapheneInstigationStateNotFoundError,
+            GraphenePythonError,
+        )
 
 
 class GrapheneInstigationStatesOrError(graphene.Union):
@@ -464,6 +492,7 @@ types = [
     GrapheneFutureInstigationTicks,
     GrapheneInstigationTypeSpecificData,
     GrapheneInstigationState,
+    GrapheneInstigationStateNotFoundError,
     GrapheneInstigationStateOrError,
     GrapheneInstigationStates,
     GrapheneInstigationStatesOrError,
