@@ -1,20 +1,20 @@
 from typing import List
 
 import graphene
-import yaml
 from dagster_graphql.implementation.events import iterate_metadata_entries
 from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
 import dagster._check as check
-from dagster.core.events import DagsterEventType
-from dagster.core.host_representation.external import ExternalExecutionPlan, ExternalPipeline
-from dagster.core.host_representation.external_data import ExternalPresetData
-from dagster.core.storage.pipeline_run import PipelineRunStatus, RunRecord, RunsFilter
-from dagster.core.storage.tags import TagType, get_tag_type
-from dagster.utils import datetime_as_float
+from dagster._core.events import DagsterEventType
+from dagster._core.host_representation.external import ExternalExecutionPlan, ExternalPipeline
+from dagster._core.host_representation.external_data import ExternalPresetData
+from dagster._core.storage.pipeline_run import PipelineRunStatus, RunRecord, RunsFilter
+from dagster._core.storage.tags import REPOSITORY_LABEL_TAG, TagType, get_tag_type
+from dagster._utils import datetime_as_float
+from dagster._utils.yaml_utils import dump_run_config_yaml
 
 from ...implementation.events import from_event_record
-from ...implementation.fetch_assets import get_assets_for_run_id
+from ...implementation.fetch_assets import get_assets_for_run_id, get_unique_asset_id
 from ...implementation.fetch_pipelines import get_pipeline_reference_or_raise
 from ...implementation.fetch_runs import get_runs, get_stats, get_step_stats
 from ...implementation.fetch_schedules import get_schedules_for_pipeline
@@ -123,7 +123,15 @@ class GrapheneAsset(graphene.ObjectType):
         self._definition = definition
 
     def resolve_id(self, _):
-        return self.key
+        # If the asset is not a SDA asset (has no definition), the id is the asset key
+        # Else, return a unique idenitifer containing the repository location and name
+        if self._definition:
+            return get_unique_asset_id(
+                self.key,
+                self._definition.repository_location.name,
+                self._definition.external_repository.name,
+            )
+        return get_unique_asset_id(self.key)
 
     def resolve_assetMaterializations(self, graphene_info, **kwargs):
         from ...implementation.fetch_assets import get_asset_materializations
@@ -347,9 +355,7 @@ class GrapheneRun(graphene.ObjectType):
         return self._pipeline_run.step_keys_to_execute
 
     def resolve_runConfigYaml(self, _graphene_info):
-        return yaml.dump(
-            self._pipeline_run.run_config, default_flow_style=False, allow_unicode=True
-        )
+        return dump_run_config_yaml(self._pipeline_run.run_config)
 
     def resolve_runConfig(self, _graphene_info):
         return self._pipeline_run.run_config
@@ -414,10 +420,14 @@ class GrapheneRun(graphene.ObjectType):
         if run_record.start_time is None and self._pipeline_run.status in STARTED_STATUSES:
             # Short-circuit if pipeline failed to start, so it has an end time but no start time
             if run_record.end_time is not None:
-                return None
+                return run_record.end_time
 
             if self._run_stats is None or self._run_stats.start_time is None:
                 self._run_stats = graphene_info.context.instance.get_run_stats(self.runId)
+
+            if self._run_stats.start_time is None and self._run_stats.end_time:
+                return self._run_stats.end_time
+
             return self._run_stats.start_time
         return run_record.start_time
 
@@ -571,7 +581,16 @@ class GrapheneIPipelineSnapshotMixin:
         return self.get_represented_pipeline().solid_selection
 
     def resolve_runs(self, graphene_info, **kwargs):
-        runs_filter = RunsFilter(pipeline_name=self.get_represented_pipeline().name)
+        pipeline = self.get_represented_pipeline()
+        if isinstance(pipeline, ExternalPipeline):
+            runs_filter = RunsFilter(
+                pipeline_name=pipeline.name,
+                tags={
+                    REPOSITORY_LABEL_TAG: pipeline.get_external_origin().external_repository_origin.get_label()
+                },
+            )
+        else:
+            runs_filter = RunsFilter(pipeline_name=pipeline.name)
         return get_runs(graphene_info, runs_filter, kwargs.get("cursor"), kwargs.get("limit"))
 
     def resolve_schedules(self, graphene_info):
@@ -665,10 +684,7 @@ class GraphenePipelinePreset(graphene.ObjectType):
         return self._active_preset_data.solid_selection
 
     def resolve_runConfigYaml(self, _graphene_info):
-        yaml_str = yaml.safe_dump(
-            self._active_preset_data.run_config, default_flow_style=False, allow_unicode=True
-        )
-        return yaml_str if yaml_str else ""
+        return dump_run_config_yaml(self._active_preset_data.run_config) or ""
 
     def resolve_mode(self, _graphene_info):
         return self._active_preset_data.mode
